<?php
class ControllerExtensionModuleRoutee extends Controller {
	private $error = array();

	public function index() {
		$this->load->language('extension/module/routee');

		$this->document->setTitle($this->language->get('heading_title'));

        $data['heading_title']  = $this->language->get('heading_title');
        $data['text_edit']      = $this->language->get('text_edit');
        $data['entry_status']   = $this->language->get('entry_status');
        $data['entry_username'] = $this->language->get('entry_username');
        $data['entry_password'] = $this->language->get('entry_password');
        $data['entry_uuid']     = $this->language->get('entry_uuid');
        $data['text_enabled']   = $this->language->get('text_enabled');
        $data['text_disabled']  = $this->language->get('text_disabled');
        $data['button_save']    = $this->language->get('button_save');
        $data['button_cancel']  = $this->language->get('button_cancel');

		$this->load->model('setting/setting');

		if (($this->request->server['REQUEST_METHOD'] == 'POST') && $this->validate()) {
			$resultJson = $this->getAuthenticate($this->request->post);
			
			if(!isset($resultJson)) {
				$this->session->data['warning'] = 'The username or password in incorrect. Visit <a href="https://go.routee.net">https://go.routee.net</a> to create your account and try again.';
				$this->response->redirect($this->url->link('extension/module/routee', 'token=' . $this->session->data['token'], true));
			} else {
				if(isset($resultJson['message']) && ($resultJson['message'] == "Authorization succeed")) {
					if($this->config->get('module_routee_uuid') == "") {
						$this->request->post['module_routee_uuid'] = $resultJson['uuid'];
					}
					$this->model_setting_setting->editSetting('module_routee', $this->request->post);
					
					$this->session->data['success'] = $this->language->get('text_success');
					$this->response->redirect($this->url->link('extension/module/routee', 'token=' . $this->session->data['token'], true));
				} else {
					$this->session->data['warning'] = 'The username or password in incorrect. Visit <a href="https://go.routee.net">https://go.routee.net</a> to create your account and try again.';
					$this->response->redirect($this->url->link('extension/module/routee', 'token=' . $this->session->data['token'], true));
				}
			}
		}

		if (isset($this->error['warning'])) {
			$data['error_warning'] = $this->error['warning'];
		} else {
			$data['error_warning'] = '';
		}
		
		if (isset($this->session->data['warning'])) {
			$data['error_warning'] = $this->session->data['warning'];
			unset($this->session->data['warning']);
		} else {
			$data['error_warning'] = '';
		}
		
		if (isset($this->session->data['success'])) {
			$data['success'] = $this->session->data['success'];
			unset($this->session->data['success']);
		} else {
			$data['success'] = '';
		}
		
		if (isset($this->error['username'])) {
			$data['error_username'] = $this->error['username'];
		} else {
			$data['error_username'] = '';
		}
		
		if (isset($this->error['password'])) {
			$data['error_password'] = $this->error['password'];
		} else {
			$data['error_password'] = '';
		}

		$data['breadcrumbs'] = array();

		$data['breadcrumbs'][] = array(
			'text' => $this->language->get('text_home'),
			'href' => $this->url->link('common/dashboard', 'token=' . $this->session->data['token'], true)
		);

		$data['breadcrumbs'][] = array(
			'text' => $this->language->get('text_extension'),
			'href' => $this->url->link('marketplace/extension', 'token=' . $this->session->data['token'] . '&type=module', true)
		);

		$data['breadcrumbs'][] = array(
			'text' => $this->language->get('heading_title'),
			'href' => $this->url->link('extension/module/routee', 'token=' . $this->session->data['token'], true)
		);
		$data['action'] = $this->url->link('extension/module/routee', 'token=' . $this->session->data['token'], true);

		$data['cancel'] = $this->url->link('marketplace/extension', 'token=' . $this->session->data['token'] . '&type=module', true);

		if (isset($this->request->post['module_routee_status'])) {
			$data['module_routee_status'] = $this->request->post['module_routee_status'];
		} else {
			$data['module_routee_status'] = $this->config->get('module_routee_status');
		}
		
		if (isset($this->request->post['module_routee_username'])) {
			$data['module_routee_username'] = $this->request->post['module_routee_username'];
		} else {
			$data['module_routee_username'] = $this->config->get('module_routee_username');
		}
		
		if (isset($this->request->post['module_routee_password'])) {
			$data['module_routee_password'] = $this->request->post['module_routee_password'];
		} else {
			$data['module_routee_password'] = $this->config->get('module_routee_password');
		}
		
		if (isset($this->request->post['module_routee_uuid'])) {
			$data['module_routee_uuid'] = $this->request->post['module_routee_uuid'];
		} else {
			$data['module_routee_uuid'] = $this->config->get('module_routee_uuid');
		}

        $data['module_routee_customer_exported']    = $this->config->get('module_routee_customer_exported') ?: 0;
        $data['module_routee_newsletter_exported']  = $this->config->get('module_routee_newsletter_exported') ?: 0;
        $data['module_routee_order_exported']       = $this->config->get('module_routee_order_exported') ?: 0;
        $data['module_routee_product_exported']     = $this->config->get('module_routee_product_exported') ?: 0;
        $data['module_routee_wishlist_exported']    = $this->config->get('module_routee_wishlist_exported') ?: 0;

		$data['header'] = $this->load->controller('common/header');
		$data['column_left'] = $this->load->controller('common/column_left');
		$data['footer'] = $this->load->controller('common/footer');

		$this->response->setOutput($this->load->view('extension/module/routee', $data));
	}
	
	public function uninstall() {
		if($this->config->get('module_routee_uuid') != "")
		{
			$customerCartValue = array();
					
			$customerCartValue['data'] = array();
			$customerCartValue["uuid"] = $this->config->get('module_routee_uuid');
			$customerCartValue["event"] = 'Uninstall';
			
			$postData = json_encode($customerCartValue);
	
			$ch = curl_init('https://idata.routee.net/api/event');
			curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "POST");
			curl_setopt($ch, CURLOPT_POSTFIELDS, $postData);                                                                  
			curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
			$result = curl_exec($ch);
			
			$this->load->library('routee');
			$this->routee->write("Uninstall: ".json_encode($customerCartValue)." Result: ".$result);
			
			$resultJson = json_decode($result, 1);
		}
	}

	protected function validate() {
		if (!$this->user->hasPermission('modify', 'extension/module/routee')) {
			$this->error['warning'] = $this->language->get('error_permission');
		}
		
		// Check Response
		if (!$this->request->post['module_routee_username']) {
			$this->error['username'] = $this->language->get('error_username');
		}

		if (!$this->request->post['module_routee_password']) {
			$this->error['password'] = $this->language->get('error_password');
		}
		

		return !$this->error;
	}
	
	public function getAuthenticate($post) {
		$postData = [
			"username" => $post['module_routee_username'],
			"password" => $post['module_routee_password'],
			"source" => "Opencart",
			"type" => "E-Commerce",
			"version" => VERSION,
			"plugin_version" => "1.0.1.23",
			"domain" => HTTP_CATALOG
		];
		$data_string = json_encode($postData); 
		$ch = curl_init('https://waymore.routee.net/api/authenticate');
		curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "POST");
		curl_setopt($ch, CURLOPT_POSTFIELDS, $data_string);                                                                  
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);                                                                      
		curl_setopt($ch, CURLOPT_HTTPHEADER, array(                                                                          
			'Content-Type: application/json',                                                                                
			'Content-Length: ' . strlen($data_string))                                                                       
		);   
		$result = curl_exec($ch);
		$resultJson = json_decode($result, 1);
		
		return $resultJson;
	}
}
